// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PULSEAUDIOQT_VERSION_H
#define PULSEAUDIOQT_VERSION_H

#define PULSEAUDIOQT_VERSION_STRING "1.8.1"
#define PULSEAUDIOQT_VERSION_MAJOR 1
#define PULSEAUDIOQT_VERSION_MINOR 8
#define PULSEAUDIOQT_VERSION_PATCH 1
#define PULSEAUDIOQT_VERSION ((1<<16)|(8<<8)|(1))

#endif
